testmodels

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Account

type Account struct {
	gorm.Model
	Owner string `gorm:"size:120;not null"`
}

Account is a second, unrelated GORM model used by makemigrations integration tests to exercise a migration that adds one new model without repeating a model an earlier migration already covers.

type Product

type Product struct {
	gorm.Model
	Name  string `gorm:"size:120;not null"`
	Price int64  `gorm:"not null"`
}

Product is a GORM model used by makemigrations integration tests.

Jump to